==> dde-daemon_6.0.49.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bn" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>আপনার নিজস্ব ব্যবহারকারী তথ্যাবলী পরিবর্তন করার জন্য প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>আপনার নিজস্ব ব্যবহারকারী তথ্যাবলী পরিবর্তন করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>ব্যবহারকারী তথ্যাবলী পরিবর্তন করার জন্য প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>ব্যবহারকারী অ্যাকাউন্টগুলি ব্যবস্থাপনা করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>স্বয়ংক্রিয় লগইন চালু করার জন্য প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>স্বয়ংক্রিয় লগইন চালু করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>স্বয়ংক্রিয় লগইন বন্ধ করতে প্রমাণীকরণ প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>স্বয়ংক্রিয় লগইন বন্ধ করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন চালু করার জন্য প্রমাণীকরণ প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন চালু করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন বন্ধ করার জন্য প্রমাণীকরণ প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন বন্ধ করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>কীবোর্ড লেআউট সেট করতে প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>কীবোর্ড লেআউট সেট করুন</translation>
		</message>
	</context>
</TS>

==> dde-daemon_6.1.45.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_bn.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bn">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>আপনার নিজস্ব ব্যবহারকারী তথ্যাবলী পরিবর্তন করার জন্য প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>আপনার নিজস্ব ব্যবহারকারী তথ্যাবলী পরিবর্তন করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>ব্যবহারকারী তথ্যাবলী পরিবর্তন করার জন্য প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>ব্যবহারকারী অ্যাকাউন্টগুলি ব্যবস্থাপনা করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>স্বয়ংক্রিয় লগইন চালু করার জন্য প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>স্বয়ংক্রিয় লগইন চালু করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>স্বয়ংক্রিয় লগইন বন্ধ করতে প্রমাণীকরণ প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>স্বয়ংক্রিয় লগইন বন্ধ করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!message" line="0"/>
			<source>Authentication is required to enable quick login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!description" line="0"/>
			<source>Enable Quick Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!message" line="0"/>
			<source>Authentication is required to disable quick login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!description" line="0"/>
			<source>Disable Quick Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!message" line="0"/>
			<source>Authentication is required to enable WeChat code login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!description" line="0"/>
			<source>Enable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!message" line="0"/>
			<source>Authentication is required to disable WeChat code login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!description" line="0"/>
			<source>Disable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন চালু করার জন্য প্রমাণীকরণ প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন চালু করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন বন্ধ করার জন্য প্রমাণীকরণ প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>পাসওয়ার্ড ছাড়া লগইন বন্ধ করুন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>কীবোর্ড লেআউট সেট করতে প্রমাণীকরণের প্রয়োজন</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>কীবোর্ড লেআউট সেট করুন</translation>
		</message>
	</context>
</TS>
